<?php
/*
Plugin Name: Tweetstream
Plugin URI:
Description: Synchronises users tweets with activity stream and back.
Version: 1.1.4
Author: Peter Hofman
Author URI: http://www.faboo.nl
*/

// Copyright (c) 2010 Faboo.nl. All rights reserved.
//
// Released under the GPL license
// http://www.opensource.org/licenses/gpl-license.php
//
// This is an add-on for Buddypress
// http://buddypress.org/
//
// **********************************************************************
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// **********************************************************************

##############################################
##                                          ##
##             twitter oauth                ##
##                                          ##
##############################################

include 'twitter/EpiCurl.php';
include 'twitter/EpiOAuth.php';
include 'twitter/EpiTwitter.php';

##############################################
##                                          ##
##             plugin stuff                 ##
##                                          ##
##############################################

//error_reporting(1);
define ( 'BP_TWEETSTREAM_VERSION', '0.1' );
define ( 'BP_TWEETSTREAM_IS_INSTALLED', 1 );

##############################################
##                                          ##
##             local language               ##
##                                          ##
##############################################

add_action('plugins_loaded', 'tweetstream_textdomain', 9);

function tweetstream_textdomain() {
    $locale = apply_filters( 'tweetstream_textdomain', get_locale() );
    $mofile = WP_PLUGIN_DIR . "/tweetstream/languages/tweetstream-$locale.mo";
    if ( file_exists( $mofile ) ){
        load_textdomain( 'tweetstream', $mofile );
    }
}

################################################
##                                            ##
##  add extra filter option in dropdown       ##
##                                            ##
################################################

add_action('bp_activity_filter_options', 'tweetstream_addFilter',1);
add_action('bp_member_activity_filter_options', 'tweetstream_addFilter',1);

function tweetstream_addFilter() {
    echo '<option value="tweet">Show Tweets</option>';
}

################################################
##                                            ##
##  add action to add checkbox to update form ##
##                                            ##
################################################

add_action ('bp_activity_post_form_options', 'tweetstream_addCheckbox');

//add twitter checkbox to form
function tweetstream_addCheckbox() {
    global $bp;


    $user_id = $bp->loggedin_user->id;

    if(get_site_option("tweetstream_consumer_key")){

        if(get_usermeta ( $user_id, 'tweetstream_token' )){

            //add css and js
            echo'<link rel="stylesheet" href="'.plugins_url("tweetstream/css/style.css").'" type="text/css" media="screen" />';
            echo'<script type="text/javascript" src="'.plugins_url("tweetstream/js/tweetstream.js").'"></script>';

            $checkbox_on = get_usermeta ( $user_id, 'tweetstream_checkboxon' );

            if($checkbox_on==1){
                echo'<div class="tweetstream_checkbox_container"><input type="checkbox" name="activity_to_twitter" id="activity_to_twitter" value="1" onclick="addTwitter();" checked> '.__( 'To twitter', 'tweetstream' ).'</div>';
            }else{
                echo'<div class="tweetstream_checkbox_container"><input type="checkbox" name="activity_to_twitter" id="activity_to_twitter" value="1" onclick="addTwitter();"> '.__( 'To twitter', 'tweetstream' ).'</div>';
            }

        }else{
            if(get_site_option('tweetstream_user_settings_message')==1){
                echo ' <i>'.__( 'Want to tweet this message to? Check your ', 'tweetstream' ).'<a href="'.$bp->loggedin_user->domain.'settings/tweetstream">'.__( 'tweetstream settings', 'tweetstream' ).'</a>.</i>';
            }
        }
    }
}

################################################
##                                            ##
##  add action to add checkbox to forum form  ##
##                                            ##
################################################

add_action ('groups_forum_new_topic_after', 'tweetstream_addTopicCheckbox' );
add_action ('bp_after_group_forum_post_new', 'tweetstream_addTopicCheckbox' );

//add twitter checkbox to form
function tweetstream_addTopicCheckbox() {
    global $bp;

    $user_id = $bp->loggedin_user->id;

    if(get_site_option("tweetstream_consumer_key")){

        if(get_usermeta ( $user_id, 'tweetstream_token' )){

            //add css and js
            echo'<link rel="stylesheet" href="'.plugins_url("tweetstream/css/style.css").'" type="text/css" media="screen" />';
            echo'<script type="text/javascript" src="'.plugins_url("tweetstream/js/tweetstream.js").'"></script>';

            $checkbox_on = get_usermeta ( $user_id, 'tweetstream_checkboxon' );

            if($checkbox_on==1){
                echo'<br><br><div class="tweetstream_checkbox_container"><input type="checkbox" name="topic_to_twitter" id="topic_to_twitter" value="1" onclick="addTopicTwitter();" checked> '.__( 'To twitter', 'tweetstream' ).'</div>';
            }else{
                echo'<br><br><div class="tweetstream_checkbox_container"><input type="checkbox" name="topic_to_twitter" id="topic_to_twitter" value="1" onclick="addTopicTwitter();"> '.__( 'To twitter', 'tweetstream' ).'</div>';
            }

        }else{
            if(get_site_option('tweetstream_user_settings_message')==1){
                echo ' <i>'.__( 'Want to tweet this message to? Check your ', 'tweetstream' ).'<a href="'.$bp->loggedin_user->domain.'settings/tweetstream">'.__( 'tweetstream settings', 'tweetstream' ).'</a>.</i>';
            }
        }
    }
}

################################################
##                                            ##
##  add action to add checkbox to forum reply  ##
##                                            ##
################################################

add_action ('groups_forum_new_reply_after', 'tweetstream_addTopicReplyCheckbox' );

//add twitter checkbox to form
function tweetstream_addTopicReplyCheckbox() {
    global $bp;

    $user_id = $bp->loggedin_user->id;

    if(get_site_option("tweetstream_consumer_key")){

        if(get_usermeta ( $user_id, 'tweetstream_token' )){

            //add css and js
            echo'<link rel="stylesheet" href="'.plugins_url("tweetstream/css/style.css").'" type="text/css" media="screen" />';
            echo'<script type="text/javascript" src="'.plugins_url("tweetstream/js/tweetstream.js").'"></script>';

            $checkbox_on = get_usermeta ( $user_id, 'tweetstream_checkboxon' );

            if($checkbox_on==1){
                echo'<div class="tweetstream_checkbox_container"><input type="checkbox" name="topicreply_to_twitter" id="topicreply_to_twitter" value="1" onclick="addTopicReplyTwitter();" checked> '.__( 'To twitter', 'tweetstream' ).'</div><br><br>';
            }else{
                echo'<div class="tweetstream_checkbox_container"><input type="checkbox" name="topicreply_to_twitter" id="topicreply_to_twitter" value="1" onclick="addTopicReplyTwitter();"> '.__( 'To twitter', 'tweetstream' ).'</div><br><br>';
            }

        }else{
            if(get_site_option('tweetstream_user_settings_message')==1){
                echo ' <i>'.__( 'Want to tweet this message to? Check your ', 'tweetstream' ).'<a href="'.$bp->loggedin_user->domain.'settings/tweetstream">'.__( 'tweetstream settings', 'tweetstream' ).'</a>.</i>';
            }
        }
    }
}

##############################################
##                                          ##
##        add tweet when new topic          ##
##                                          ##
##############################################

add_filter( 'group_forum_topic_title_before_save', 'tweetstream_topic');

//function with params from bp_activity_add
function tweetstream_topic() {

    global $bp;

    //get loged in user id
    $user_id = $bp->loggedin_user->id;
    $title = $_POST['topic_title'];

    //check if #TWITTER is there if so then kick the content to twitter!
    $pos = strpos($title,"#TWITTER");
    $title = str_replace("#TWITTER","",$title);

    //twitter tag found
    if($pos>0){
        add_filter('bp_forums_new_topic', 'tweetstream_topicSaveId',9);        
    }

    return $title;
}

function tweetstream_topicSaveId($id){
    tweetstream_topicToTwitter($id);
    return $id;
}

function tweetstream_topicToTwitter($id){
    
    global $bp;
    
    $topic_info = bp_forums_get_topic_details($id);
    
    //get loged in user id
    $user_id = $bp->loggedin_user->id;
    $content = $_POST['topic_title'];

    //check if #TWITTER is there if so then kick the content to twitter!
    $pos = strpos($content,"#TWITTER");
    $content = str_replace("#TWITTER","",$content);

    //we found #TWITTER tag so push it to twitter
    if($pos >0) {

        //filter for url ceation
        $backlink = bp_get_group_permalink( $bp->groups->current_group ) . 'forum/topic/' . $topic_info->topic_slug . '/';

        //create short url
        $backlink = tweetstream_getShortUrl($backlink);

        //make ik small enough for twitter but never shorten the backlink
        $max_length = 113;
        if(strlen($content>$max_length))
        {
            $content = substr($content,0,$max_length);
        }

        $content .= " ".$backlink;

        tweetstream_twitterIt($content);
    }
    
}


##############################################
##                                          ##
##        add tweet when new reply          ##
##                                          ##
##############################################

add_filter('group_forum_post_text_before_save', 'tweetstream_topicReply',9);

function tweetstream_topicReply() {

    global $bp;

    //get loged in user id
    $user_id = $bp->loggedin_user->id;
    $content = $_POST['reply_text'];

    //check if #TWITTER is there if so then kick the content to twitter!
    $pos = strpos($content,"#TWITTER");
    $content = str_replace("#TWITTER","",$content);

    //twitter tag found
    if($pos>0){
        add_filter('group_forum_post_topic_id_before_save', 'tweetstream_topicReplySaveId',9);
    }

    return $content;
}

function tweetstream_topicReplySaveId($id){

    tweetstream_topicReplyToTwitter($id);
    return $id;
}

function tweetstream_topicReplyToTwitter($id){
    global $bp;

    $topic_info = bp_forums_get_topic_details($id);

    //filter for url ceation
    $backlink = bp_get_group_permalink( $bp->groups->current_group ) . 'forum/topic/' . $topic_info->topic_slug . '/';
    
    //create short url
     $backlink = tweetstream_getShortUrl($backlink);

    //make ik small enough for twitter but never shorten the backlink
    $max_length = 95;
    if(strlen($content>$max_length))
    {
        $content = substr($topic_info->topic_title,0,$max_length);
    }else{
        $content = $topic_info->topic_title;
    }

    $content = "Just responded to: ".$content." ".$backlink;

    tweetstream_twitterIt($content);

}

##############################################
##                                          ##
##        add tweet when new activity       ##
##                                          ##
##############################################

add_filter( 'bp_activity_content_before_save', 'tweetstream_activityToTwitter' );

//function with params from bp_activity_add
function tweetstream_activityToTwitter($content) {

    global $bp;

    //get loged in user id
    $user_id = $bp->loggedin_user->id;

    //check if #TWITTER is there if so then kick the content to twitter!
    $pos = strpos($content,"#TWITTER");
    $content = str_replace("#TWITTER","",$content);

    //we found #TWITTER tag so push it to twitter
    if($pos >0) {

        //strip out all html
        $tweet_content = strip_tags($content);
        $tweet_content =  stripslashes($tweet_content);

        //how long is the content?
        $lenght_content = strlen($tweet_content);

        //how long is user domain
        if(get_usermeta ( $user_id, 'tweetstream_profilelink' )==1){
            $lenght_userdomain = strlen($bp->loggedin_user->domain)+4;
            $max_length = 140-$lenght_userdomain;
            $tweet_content = substr($tweet_content,0,$max_length);

            if(strlen($tweet_content)>137){
                $tweet_content .="...";
            }

            $tweet_content .= $bp->loggedin_user->domain;

        }else{
            $max_length = 140;
            $tweet_content = substr($tweet_content,0,$max_length);
            if(strlen($tweet_content)>137){
                $tweet_content .="...";
            }
        }

        tweetstream_twitterIt($tweet_content);
    }

    return $content;
}



##############################################
##                                          ##
##  function to send content to twitter     ##
##                                          ##
##############################################

function tweetstream_twitterIt($content) {

    global $bp;

    //get loged in user id
    $user_id = $bp->loggedin_user->id;

    //content related things
    $content = htmlentities($content, ENT_COMPAT, "UTF-8");
    
    //create new twitter instance and login
    $token = get_usermeta ( $user_id, 'tweetstream_token' );
    $secret = get_usermeta ( $user_id, 'tweetstream_tokensecret' );

    $twitterObj = new EpiTwitter(get_site_option("tweetstream_consumer_key"), get_site_option("tweetstream_consumer_secret"));
    $twitterObj->setToken($token,$secret);

    $status_update = $twitterObj->post_statusesUpdate(array('status' => $content));
    $status_update->response;
}

##############################################
##                                          ##
##  add tweets to activity stream           ##
##                                          ##
##############################################

//when viewing profile get the user tweets, for performace and API restrictions only 1 time per hour.
add_action( 'bp_activity_screen_my_activity', 'tweetstream_getTweets', 9 );

function tweetstream_getTweets($limit=true) {

    global $bp;

    $user_id = $bp->displayed_user->id;

    //check if user has filled in a twitter
    if (get_usermeta ( $user_id, 'tweetstream_token' )) {

        if(get_usermeta ( $user_id, 'tweetstream_synctoac' )==1){

            //login
            $last_update = get_usermeta ( $user_id, 'tweetstream_lastupdate' );

            // log update so there is a max ratelimit of 60 (we got 150 from twitter)
            $cur_hour = date('Hi');

            //$cur_hour = 0;

            //did i do an update this hour already?
            if ($last_update != $cur_hour) {

                $token = get_usermeta ( $user_id, 'tweetstream_token' );
                $secret = get_usermeta ( $user_id, 'tweetstream_tokensecret' );

                //twitter object
                $twitterObj = new EpiTwitter(get_site_option("tweetstream_consumer_key"), get_site_option("tweetstream_consumer_secret"));
                $twitterObj->setToken($token,$secret);

                //update screenname (mention)
                $userInfo = $twitterObj->get_accountVerify_credentials();
                update_usermeta ( $user_id, 'tweetstream_mention',"@".$userInfo->response['screen_name']);

                //get users timeline
                $tweetsObj = $twitterObj->get_statusesUser_timeline();
                $tweets = $tweetsObj->response;

                $filters = get_site_option('tweetstream_filter');

                if ($tweets) {
                    foreach ( $tweets as $tweet ) {

                        //set tweet_text and filter some stuff out
                        $tweet_text = $tweet['text'];
                        $tweet_text = strip_tags($tweet_text);

                        //create new activity instance
                        $activity = new BP_Activity_Activity();

                        //filtering
                        if($filters!=""){
                            $arrFilters = explode(",",$filters);
                            if($arrFilters){
                                foreach ($arrFilters as $filter){
                                    //one of these filter has to exist
                                    $pos_filter = strpos($tweet_text,"#".$filter);
                                    if($pos_filter >0){
                                        $filter_pass = 1;
                                        
                                        //also strip out filter, no need to show it, unless admin setting says to.
                                        if(get_site_option('tweetstream_filter_show')==0){
                                            $tweet_text = str_replace("#".$filter,"",$tweet_text);
                                        }
                                        
                                    }else{
                                        $filter_pass = 0;
                                    }
                                }
                            }
                        }else{
                            $filter_pass=1;
                        }

                        //mentions filtering
                        if(get_usermeta ($user_id,'tweetstream_filtermentions')==1){
                            $pattern = '/[@]+([A-Za-z0-9-_]+)/';
                            $found_mention = preg_match( $pattern, $tweet_text );

                            if($found_mention){
                                $filter_pass = 0;
                            }
                        }

                        if($filter_pass == 1){

                            //check if activity does exist
                            $exist = $activity->check_exists_by_content($tweet_text);

                            //does the tweet comes from us?
                            $tweet_source = $tweet['source'];
                            $tweet_source_array = explode('"',$tweet_source);
                            if($tweet_source_array[1]==$bp->root_domain){
                                $exist = 1;
                            }

                            //new activity!
                            if ($exist == 0 ) {
                                //convert tweet time to timestamp
                                $date_recorded = strtotime($tweet['created_at']);
                                $date_recorded = gmdate('Y-m-d H:i:s',$date_recorded);

                                $activity = new BP_Activity_Activity ();
                                $activity->user_id = $user_id;
                                $activity->component = "tweetstream";
                                $activity->type = "tweet";
                                $activity->action = '<a href="'.$bp->root_domain.'/members/'.$bp->displayed_user->userdata->user_login.'/" title="'.$bp->displayed_user->userdata->user_login.'">'.$bp->displayed_user->fullname.'</a><a href="http://www.twitter.com/' . $tweet['user']['screen_name'] . '"><img src="/wp-content/plugins/tweetstream/twitter-icon.png"></a> posted a <a href="http://www.twitter.com/' . $tweet['user']['screen_name'] . '">tweet</a>:';
                                $activity->content = $tweet_text;
                                $activity->primary_link = "";
                                $activity->secondary_item_id = $tweet['id'];
                                $activity->date_recorded = $date_recorded;
                                $activity->hide_sitewide = 0;
                                $activity->save ();
                            }
                        }
                    }
                }

                //update last update hour
                update_usermeta ( ( int ) $bp->loggedin_user->id, 'tweetstream_lastupdate', attribute_escape ( date ( 'Hi' ) ) );
            }
        }
    }
}


##############################################
##                                          ##
##  delete tweet from twitter when deleting ##
##  activity item (if tweetstream)          ##
##                                          ##
##############################################

add_action( 'bp_activity_action_delete_activity', 'tweetstream_deletetweet', 10, 2 );

//function with params from bp_activity_delete
function tweetstream_deleteTweet($activity_id,$user_id) {

    global $bp;

    //get loged in user id
    $user_id = $bp->loggedin_user->id;

    $deletetweet = get_usermeta ( $user_id, 'tweetstream_deletetweet' );

    if($deletetweet==1){
        //get activity details
        $activity = new BP_Activity_Activity( $activity_id );

        //get type component and tweet_id
        $type      = $activity->type ;
        $component = $activity->component;
        $tweet_id  = $activity->secondary_item_id;

        //componement tweetstream and type tweet?
        if($component=="tweetstream" && $type=="tweet"){

            //create new twitter instance and login
            $token = get_usermeta ( $user_id, 'tweetstream_token' );
            $secret = get_usermeta ( $user_id, 'tweetstream_tokensecret' );

            $twitterObj = new EpiTwitter(get_site_option("tweetstream_consumer_key"), get_site_option("tweetstream_consumer_secret"));
            $twitterObj->setToken($token,$secret);

            $status_delete = $twitterObj->post_statusesDestroy(array('id' => $tweet_id));
            $status_delete->response;

        }
    }
    return true;
}

##############################################
##                                          ##
##      Tweetstream user settings page      ##
##                                          ##
##############################################

function tweetstream_settings_screen() {

    global $bp;

    //security fix
    if($bp->displayed_user->id!=$bp->loggedin_user->id){
        header('location:'.$bp->root_domain);
    }

    add_action( 'bp_template_title', 'tweetstream_settings_screen_title' );
    add_action( 'bp_template_content', 'tweetstream_settings_screen_content' );
    bp_core_load_template( apply_filters( 'bp_core_template_plugin', 'members/single/plugins' ) );
}


function tweetstream_settings_screen_title() {
    _e( 'Tweetstream', 'buddypress' );
}

function tweetstream_settings_screen_content() {

    global $bp;

    $user_id = $bp->loggedin_user->id;

    $twitterObj = new EpiTwitter(get_site_option("tweetstream_consumer_key"),get_site_option("tweetstream_consumer_secret"));

    if($_POST){

        update_usermeta ( $user_id, 'tweetstream_deletetweet',$_POST['tweetstream_deletetweet'] );
        update_usermeta ( $user_id, 'tweetstream_checkboxon',$_POST['tweetstream_checkboxon']);
        update_usermeta ( $user_id, 'tweetstream_synctoac',$_POST['tweetstream_synctoac']);
        update_usermeta ( $user_id, 'tweetstream_profilelink',$_POST['tweetstream_profilelink']);
        update_usermeta ( $user_id, 'tweetstream_filtermentions',$_POST['tweetstream_filtermentions']);


        echo' <div id="message" class="updated fade">
				<p>'.__( 'Settings saved', 'tweetstream' ).'</p>
			</div>
		';
    }

    $tweetstream_deletetweet = get_usermeta ( $user_id, 'tweetstream_deletetweet' );
    $tweetstream_checkboxon = get_usermeta ( $user_id, 'tweetstream_checkboxon' );
    $tweetstream_synctoac = get_usermeta ( $user_id, 'tweetstream_synctoac' );
    $tweetstream_profilelink = get_usermeta ( $user_id, 'tweetstream_profilelink' );
    $tweetstream_filtermentions = get_usermeta ( $user_id, 'tweetstream_filtermentions' );

    if(get_usermeta ( $user_id, 'tweetstream_token' )){

        echo '<form id="settings_form" action="'.$bp->loggedin_user->domain.'settings/tweetstream/" method="post">
        <h3>Tweetstream settings</h3>
        ';
        echo '<b>'.__( 'Permission', 'tweetstream' ).'</b><br>'.__( 'You already gave permission.', 'tweetstream' ).'<br/> '.__( 'To disallow click the button below and choose "Deny"', 'tweetstream' ).'</b><br><br>';

			?>
		
		<input type="button" value="<?php echo __( 'Authorize with twitter', 'tweetstream' );?>" onclick="location.href='<?php echo $twitterObj->getAuthorizationUrl();?>';"><br/><br/>
				
		<table id="activity-notification-settings" class="notification-settings">
    		<tbody><tr class="alt">
    			<th class="icon"></th>
    			<th class="title"><?php echo __( 'Otions', 'tweetstream' );?></th>
    			<th class="yes"><?php echo __( 'Yes', 'tweetstream' );?></th>
    			<th class="no"><?php echo __( 'No', 'tweetstream' );?></th>
    		</tr>
    
    		<tr>
    			<td></td>
    			<td><?php echo __( 'Delete tweet from twitter when deleted in activity.', 'tweetstream' );?></td>
    			<td class="yes"><input type="radio" name="tweetstream_deletetweet" id="tweetstream_deletetweet" value="1" <?php if($tweetstream_deletetweet==1){echo'checked';}?>></td>
    			<td class="no"><input type="radio" name="tweetstream_deletetweet" id="tweetstream_deletetweet" value="0" <?php if($tweetstream_deletetweet==0){echo'checked';}?>></td>
    		</tr>
    		
    		
    		<tr class="alt">
    			<td></td>
    			<td><?php echo __( 'Always check checkbox "To twitter"'  , 'tweetstream' );?></td>
    			<td class="yes"><input type="radio" name="tweetstream_checkboxon" id="tweetstream_checkboxon" value="1" <?php if($tweetstream_checkboxon==1){echo'checked';}?>></td>
    			<td class="no"><input type="radio" name="tweetstream_checkboxon" id="tweetstream_checkboxon" value="0" <?php if($tweetstream_checkboxon==0){echo'checked';}?>></td>
    		</tr>
    		
    		<tr>
    			<td></td>
    			<td><?php echo __( 'Synchronize tweets to my activity'  , 'tweetstream' );?></td>
    			<td class="yes"><input type="radio" name="tweetstream_synctoac" id="tweetstream_synctoac" value="1" <?php if($tweetstream_synctoac==1){echo'checked';}?>></td>
    			<td class="no"><input type="radio" name="tweetstream_synctoac" id="tweetstream_synctoac" value="0" <?php if($tweetstream_synctoac==0){echo'checked';}?>></td>
    		</tr>
    		
    		<tr class="alt">
    			<td></td>
    			<td><?php echo __( 'Import tweets containing @names' , 'tweetstream' );?></td>
    			<td class="yes"><input type="radio" name="tweetstream_filtermentions" id="tweetstream_filtermentions" value="0" <?php if($tweetstream_filtermentions==0){echo'checked';}?>></td>
    			<td class="no"><input type="radio" name="tweetstream_filtermentions" id="tweetstream_filtermentions" value="1" <?php if($tweetstream_filtermentions==1){echo'checked';}?>></td>
    		</tr>
    
    		<tr>
    			<td></td>
    			<td><?php echo __( 'Add my profile link after my tweet'  , 'tweetstream' );?></td>
    			<td class="yes"><input type="radio" name="tweetstream_profilelink" id="tweetstream_profilelink" value="1" <?php if($tweetstream_profilelink==1){echo'checked';}?>></td>
    			<td class="no"><input type="radio" name="tweetstream_profilelink" id="tweetstream_profilelink" value="0" <?php if($tweetstream_profilelink==0){echo'checked';}?>></td>
    		</tr>
    		
    		
			</tbody></table>
			
			<input type="submit" value="<?php echo __( 'Save settings', 'tweetstream' );?>">
			
			<?php

			echo '</form>';
    }else{

        echo'<b>'.__( 'Permission', 'tweetstream' ).'</b><br>'.__( 'You can setup your tweetstream over here.', 'tweetstream' ).'<br>
			'.__( 'Before u can see al settings please authorize on twitter, to do so click on the link below.', 'tweetstream' ).'<br><br>';
        echo '<a href="' . $twitterObj->getAuthorizationUrl() . '">'.__( 'Authorize with twitter', 'tweetstream' ).'</a>';
    }
}

##############################################
##                                          ##
##             setup navigation             ##
##                                          ##
##############################################

function tweetstream_setup_nav() {
    global $bp;

    if(get_site_option("tweetstream_consumer_key")){
        bp_core_new_subnav_item( array ('name' => __ ( 'Tweetstream', 'tweetstream' ), 'slug' => 'tweetstream', 'parent_url' => $bp->loggedin_user->domain . 'settings/', 'parent_slug' => 'settings', 'screen_function' => 'tweetstream_settings_screen', 'position' => 40 ) );
    }
}

add_action ( 'plugins_loaded', 'tweetstream_setup_nav' );

##############################################
##                                          ##
##               admin page                 ##
##                                          ##
##############################################

add_action('admin_menu', 'tweetstream_admin');

function tweetstream_admin() {
    add_menu_page('Tweetstream plugin settings', 'Tweetstream', 'administrator', __FILE__, 'tweetstream_settings',plugins_url('images/icon-small.png', __FILE__));
}

function tweetstream_settings() {
    global $bp;

    if($_POST){

        update_site_option( 'tweetstream_filter',trim(strip_tags($_POST['tweetstream_filter'])));
        update_site_option( 'tweetstream_filter_show',trim(strip_tags($_POST['tweetstream_filter_show'])));
        update_site_option( 'tweetstream_consumer_key',trim(strip_tags($_POST['tweetstream_consumer_key'])));
        update_site_option( 'tweetstream_consumer_secret',trim(strip_tags($_POST['tweetstream_consumer_secret'])));
        update_site_option( 'tweetstream_user_settings_message',trim(strip_tags($_POST['tweetstream_user_settings_message'])));

        echo '<div class="updated" style="margin-top:50px;"><p><strong>'.__( 'Settings saved.', 'tweetstream' ).'</strong></p></div>';
    }
?>
<div class="wrap">

<br/><img src="<?php echo plugins_url('images/icon.png', __FILE__);?>" style="float:left;"><h2 style="float:left; line-height:5px; padding-left:5px;">Tweetstream</h2><br/>

<form method="post" action="">
    <table class="form-table">
        <?php echo __( '', 'tweetstream' );?>
        <tr>
            <td colspan="2" scope="row">
            <b><?php echo __( 'Twitter API', 'tweetstream' );?></b><br/>

            <?php echo __( 'For the plugin to work you need to get an API key from twitter.', 'tweetstream' );?><br/><br/>
            <?php echo __( 'To get one follow the next steps:', 'tweetstream' );?><br/>
            <?php echo __( '&nbsp;&nbsp;&nbsp;1. Go to ', 'tweetstream' );?>"<a href="http://www.twitter.com/apps" target="_blank">http://www.twitter.com/apps</a>" <?php echo __( ' and login with your twitter account.', 'tweetstream' );?><br/>
            <?php echo __( '&nbsp;&nbsp;&nbsp;2. Create a new app wich has read/write settings, type browser (not client) and a callback url to: ', 'tweetstream' );?><b><?php echo $bp->root_domain;?></b><br/>
            <?php echo __( '&nbsp;&nbsp;&nbsp;3. Fill in the consumer key and consumer secret below.', 'tweetstream' );?><br/>     
            
            </td>
        </tr>
    <tr valign="top">
        <th scope="row"><?php echo __( 'Consumer key:', 'tweetstream' );?></th>
        <td><input type="text" name="tweetstream_consumer_key" value="<?php echo get_site_option('tweetstream_consumer_key'); ?>" size="50"/></td>
        </tr>
         
        <tr valign="top">
        <th scope="row"><?php echo __( 'Consumer secret key:', 'tweetstream' );?></th>
        <td><input type="text" name="tweetstream_consumer_secret" value="<?php echo get_site_option('tweetstream_consumer_secret'); ?>" size="50"/></td>
        </tr>
        
          <tr>
            <td colspan="2" scope="row">
            <h2><?php echo __( 'Filters (optional)', 'tweetstream' );?></h2><br>
            <?php echo __( 'Filters preventing to get a really messy activity streams.', 'tweetstream' );?><br>
            <?php echo __( 'Example: You have an social network wich focus is on soccer, you don\'t want all tweets of your users showing up that hasn\'t to do anything with soccer.', 'tweetstream' );?><br>
            <?php echo __( 'you can set the filter to "soccer", now only tweets with "#soccer" will be shown of the users tweets".', 'tweetstream' );?><br>
            <?php echo __( 'By comma seperating words you can set-up multiple filters.', 'tweetstream' );?><br>
            <?php echo __( 'No filter = all tweets.', 'tweetstream' );?>
            
            </td>
        </tr>
        
        <tr valign="top">
        <th scope="row"><?php echo __( 'Filters (comma seperated)', 'tweetstream' );?></th>
        <td><input type="text" name="tweetstream_filter" value="<?php echo get_site_option('tweetstream_filter'); ?>" size="50"/></td>
        </tr>
        
        <tr valign="top">
            <th scope="row"><?php echo __( 'Show filters in tweets.', 'tweetstream' );?></th>
            <th>
            <input type="radio" name="tweetstream_filter_show" id="tweetstream_filter_show" value="1" <?php if(get_site_option('tweetstream_filter_show')==1){echo'checked';}?>> <?php echo __( 'Yes', 'tweetstream' );?>
			<input type="radio" name="tweetstream_filter_show" id="tweetstream_filter_show" value="0" <?php if(get_site_option('tweetstream_filter_show')==0){echo'checked';}?>> <?php echo __( 'No', 'tweetstream' );?>
            </th>
        </tr>
        
        
         <tr valign="top">
        <th scope="row"><h2><?php echo __( 'User options', 'tweetstream' );?></h2></th>
        <td></td>
        </tr>
        
        <tr valign="top">
            <th><?php echo __( 'Show "Want to tweet this message to?..." message on user page.', 'tweetstream' );?></th>
            <th>
            <input type="radio" name="tweetstream_user_settings_message" id="tweetstream_user_settings_message" value="1" <?php if(get_site_option('tweetstream_user_settings_message')==1){echo'checked';}?>> <?php echo __( 'Yes', 'tweetstream' );?>
			<input type="radio" name="tweetstream_user_settings_message" id="tweetstream_user_settings_message" value="0" <?php if(get_site_option('tweetstream_user_settings_message')==0){echo'checked';}?>> <?php echo __( 'No', 'tweetstream' );?>
            </th>
        </tr>
        
         
        
    </table>
    <p class="submit">
    <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
    </p>
</form>

<h2>Donate</h2>

Do do like this plugin? Please donate, so i can stay improving this plugin and give support.<br/><br/>
<a href="https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=TKBY4JM6WDSD2" target="_blank"><img src="https://www.paypal.com/en_US/i/btn/btn_donate_LG.gif"></a>
<br/><br/>




</div>
<?php } 

##############################################
##                                          ##
##          oauth back from twitter         ##
##                                          ##
##############################################

add_action('wp','oauthcheck');

function oauthcheck(){
    global $bp;

    if($_GET['oauth_token']){

        $twitterObj = new EpiTwitter(get_site_option("tweetstream_consumer_key"), get_site_option("tweetstream_consumer_secret"));
        $twitterObj->setToken($_GET['oauth_token']);
        $token = $twitterObj->getAccessToken();
        $twitterObj->setToken($token->oauth_token, $token->oauth_token_secret);
        $twitterInfo= $twitterObj->get_accountVerify_credentials();
        $twitterInfo->response;

        update_usermeta ( ( int ) $bp->loggedin_user->id, 'tweetstream_token',$token->oauth_token );
        update_usermeta ( ( int ) $bp->loggedin_user->id, 'tweetstream_tokensecret',$token->oauth_token_secret );
        update_usermeta ( ( int ) $bp->loggedin_user->id, 'tweetstream_synctoac',1);

        //redirect to tweetstream settings
        header('location:'.$bp->loggedin_user->domain."settings/tweetstream");
    }

    if($_GET['denied']){

        update_usermeta ( ( int ) $bp->loggedin_user->id, 'tweetstream_token','');
        update_usermeta ( ( int ) $bp->loggedin_user->id, 'tweetstream_tokensecret','');
        update_usermeta ( ( int ) $bp->loggedin_user->id, 'tweetstream_synctoac','');

        //redirect to tweetstream settings
        header('location:'.$bp->loggedin_user->domain."settings/tweetstream");
    }
}

##############################################
##                                          ##
##      shorten url functions               ##
##                                          ##
##############################################

function tweetstream_getShortUrl($url){
    global $bp;

    $input = date('dmyhis');
    $index = "abcdefghijklmnopqrstuvwxyz0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ";
    $base  = strlen($index);

    for ($t = floor(log($input, $base)); $t >= 0; $t--) {
        $bcp = bcpow($base, $t);
        $a   = floor($input / $bcp) % $base;
        $out = $out . substr($index, $a, 1);
        $input  = $input - ($a * $bcp);
    }

    $shortId = strrev($out);

    update_usermeta ($bp->loggedin_user->id,'tweetstream_'.$shortId,$url);
    $url = $bp->root_domain.'/'.$shortId;

    return $url;
}

add_action('wp','tweetstream_resolveShortUrl');

function tweetstream_resolveShortUrl($url){

    global $wpdb;

    //resolving hooked to 404
    if(is_404()){
        $short_id = str_replace("/","",$_SERVER['REQUEST_URI']);
        if($short_id){
            $usermeta = $wpdb->get_row("SELECT * FROM {$wpdb->usermeta} WHERE meta_key='tweetstream_".$short_id."'");
            $url = $usermeta->meta_value;
            if($url){
                header('location:'.$url);
            }
        }
    }
}
?>